@@ -187,6 +187,32 @@ erc20_approve_abi = """
 }]
 """
 
+erc20_transfer_abi = """
+【{
+  "constant": false,
+  "inputs": [
+    {
+      "name": "recipient",
+      "type": "address"
+    },
+    {
+      "name": "amount",
+      "type": "uint256"
+    }
+  ],
+  "name": "transfer",
+  "outputs": [
+    {
+      "name": "",
+      "type": "bool"
+    }
+  ],
+  "payable": false,
+  "stateMutability": "nonpayable",
+  "type": "function"
+}】
+""" 
+
 def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token = "usdc", **kwargs):
     """
       kwargs need to include providers from different chains
@@ -198,6 +224,7 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
     """
     print(f"receiver: {receiver}, amount: {amount}, run_mode: {run_mode}, chain: {chain}, token: {token}, kwargs: {kwargs}, step: {step}")
     token_raw = token
+    token = w3.to_checksum_address(token_mapping[chain.lower()][token.lower()])
     info = None
     executor = kwargs.get("executor")
     redis_client = kwargs.get("redis_client")
@@ -400,11 +427,13 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
           receiver = res
           to = w3.to_checksum_address(receiver)
           params = {
-            'receiver': to,
+            'recipient': to,
             'amount': amount,
-            'chain': chain,
-            'token': token_raw,
-            'run_mode': run_mode
+            'chainId': chain_id_mapping[chain.lower()],
+            'contract': token,
+            'func': 'transfer',
+            'token': token,
+            'abi': erc20_transfer_abi
           }
           action_data = ActionData(func='transfer', group='transfer', params=params)
           action = Action(msg=None, type='wallet', data=action_data.__dict__)
